Skip to contents

Create a table of which models have been run on each trait.

Usage

is_Ran(folder = "GWAS_Results/", myY)

Arguments

folder

Folder containing GWAS results.

myY

Phenotype file with traits as column names which will be checked for GWAS results.

Value

A table of which models have been run on each trait.