Skip to contents

Usage

checkNYCvsKansas(folder = "GWAS_Results/", deleteKansas = F)

Arguments

folder

Folder containing GWAS results.

deteleKansas

Logical, if TRUE, will delete any Kansas files with no difference between the NYC files.

Value

A table indicating the number of markers with different p values between NYC and Kansas files.