Skip to contents

Create a table of which models have been run on each trait.

Usage

is_Ran(myY, folder = "GWAS_Results/")

Arguments

myY

Phenotype file with traits as column names which will be checked for GWAS results.

folder

Folder containing GWAS results.

Value

A table of which models have been run on each trait.